import RequireAuth from '@/components/RequireAuth'
import axiosServer from '@/services/axiosServer'
import { User } from '@/types/profile.type'
import {
  HydrationBoundary,
  QueryClient,
  dehydrate,
} from '@tanstack/react-query'
import Navigation from './Navigation'
import { Suspense } from 'react'

export const dynamic = 'force-dynamic'

export default async function ProfileLayout({
  children,
}: Readonly<{
  children: React.ReactNode
}>) {
  const queryClient = new QueryClient()
  await queryClient.prefetchQuery({
    queryKey: ['account'],
    queryFn: async (): Promise<User | undefined> => {
      const res = await axiosServer('api/account')
      return res.data.data
    },
  })

  return (
    <RequireAuth>
      <div className='container pb-8'>
        <div className='flex items-start gap-8 md:flex-col'>
          <HydrationBoundary state={dehydrate(queryClient)}>
            <Suspense fallback={<div>Loading...</div>}>
              <Navigation />
            </Suspense>
            {children}
          </HydrationBoundary>
        </div>
      </div>
    </RequireAuth>
  )
}
