'use client'

import { useSearchParams } from 'next/navigation'
import { Suspense } from 'react'

import { keepPreviousData, useQuery } from '@tanstack/react-query'

import ProductCard from '@/components/cards/ProductCard'
import Pagination from '@/components/ui/pagination'
import { getProducts } from '@/server/getProducts'

import Sort from './Sort'
import Filter from './_filter/Filter'

const Store = () => {
  const searchParams = useSearchParams()
  const page = searchParams.get('page') || '1'
  const { data: productsData } = useQuery({
    queryKey: [
      'products',
      {
        page,
        ...Object.fromEntries(searchParams),
      },
    ],
    queryFn: () => getProducts({ searchParams }),
    staleTime: 1000 * 60 * 60,
    placeholderData: keepPreviousData,
  })

  // console.log('🚀 ~ file: Store.tsx:30 ~ productsData:', productsData)
  return (
    <div className='container relative flex items-start gap-8 pb-8 md:flex-col'>
      <Suspense fallback={<div>Loading...</div>}>
        <Filter />
      </Suspense>
      <div className=' flex w-full flex-col gap-4 md:w-full'>
        <h1 className='text-2xl font-bold'>Օնլայն խանութ</h1>
        <Suspense fallback={<div>Loading...</div>}>
          <Sort />
        </Suspense>
        <div className='grid grid-cols-3 gap-4 lg:grid-cols-2 sm:grid-cols-1'>
          {productsData?.data.map((product) => (
            <ProductCard key={product.haysell_id} product={product} />
          ))}
        </div>
        {productsData?.data && productsData.data.length > 0 ? (
          <Suspense fallback={<div>Loading...</div>}>
            <Pagination totalPages={productsData?.meta.last_page || 1} />
          </Suspense>
        ) : (
          <div className='w-full p-10 text-center text-xl font-bold'>
            Ապրանքներ չեն գտնվել
          </div>
        )}
      </div>
    </div>
  )
}

export default Store
