'use client'

import { useParams, useSearchParams } from 'next/navigation'

import { useRouter } from 'next-nprogress-bar'

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from '@/components/ui/accordion'
import { Checkbox } from '@/components/ui/checkbox'
import { Label } from '@/components/ui/label'
import type { Stone, StoreType } from '@/types/store.type'

const FilterIt = ({
  title,
  items,
  name,
  type,
  subType,
  // openValues,
  // setOpenValues,
}: {
  title: string
  items: StoreType[] | Stone[]
  name: 'balance' | 'type' | 'stone' | 'filter'
  type?: string
  subType?: string
  // openValues: string[]
  // setOpenValues: React.Dispatch<React.SetStateAction<string[]>>
}) => {
  const params = useParams()
  const router = useRouter()
  const searchParams = useSearchParams()

  const createFilterUrl = (filter: string, id: number) => {
    const urlParams = new URLSearchParams(searchParams.toString())
    const stringId = String(id)

    let filterArray = urlParams.get(filter)?.split(',') || []

    if (type && !subType && filter !== 'type') {
      urlParams.set('type', type)
    }
    if (type && !subType && filter === 'type') {
      filterArray.push(type)
    }

    if (subType && filter !== 'sub_type') {
      urlParams.set('sub_type', subType)
    }
    if (subType && filter === 'sub_type') {
      filterArray.push(subType)
    }

    if (filterArray.includes(stringId)) {
      filterArray = filterArray.filter((item) => item !== stringId)
    } else {
      filterArray.push(stringId)
    }

    urlParams.set('page', '1')
    if (filterArray.length === 0) {
      urlParams.delete(filter)
    } else {
      urlParams.set(filter, filterArray.join(','))
    }

    urlParams.delete('search')
    urlParams.delete('min_price')
    urlParams.delete('max_price')

    const newUrl = `/store?${urlParams.toString()}`
    router.push(newUrl)
  }

  return (
    <Accordion type='multiple' className='w-full'>
      <AccordionItem
        value={name}
        // onClick={() => {
        //   if (openValues.includes(name)) {
        //     setOpenValues(openValues.filter((item) => item !== name))
        //   } else {
        //     setOpenValues([...openValues, name])
        //   }
        // }}
      >
        <AccordionTrigger className='py-3 text-sm font-bold hover:no-underline'>
          {title}
        </AccordionTrigger>
        <AccordionContent>
          <div className='flex flex-col gap-2'>
            {items.map((item) => {
              return (
                <div key={item.id}>
                  <Label
                    htmlFor={item.name}
                    className='flex items-center justify-between px-2 py-1'
                    onClick={() => createFilterUrl(name, item.id)}
                  >
                    <span className='flex-1'>{item.name}</span>
                    <Checkbox
                      id={item.name}
                      checked={
                        searchParams
                          .get(name)
                          ?.split(',')
                          .includes(String(item.id)) ||
                        ('slug' in item &&
                          params.slug?.length === 1 &&
                          params.slug?.includes(String(item.slug))) ||
                        false
                      }
                    />
                  </Label>
                  {'subTypes' in item && (
                    <div className='ml-5 flex flex-col gap-3 px-2 pt-3'>
                      {'subTypes' in item &&
                        item.subTypes.map((subItem) => (
                          <div
                            key={subItem.name}
                            className='flex items-center justify-between'
                            onClick={() =>
                              createFilterUrl('sub_type', subItem.id)
                            }
                          >
                            <Label className='flex-1' htmlFor={subItem.name}>
                              {subItem.name}
                            </Label>
                            <Checkbox
                              id={subItem.name}
                              checked={
                                searchParams
                                  .get('sub_type')
                                  ?.split(',')
                                  .includes(String(subItem.id)) ||
                                params.slug?.includes(String(subItem.slug)) ||
                                false
                              }
                            />
                          </div>
                        ))}
                    </div>
                  )}
                </div>
              )
            })}
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  )
}

export default FilterIt
