'use client'

import Link from 'next/link'
import { usePathname } from 'next/navigation'
import { Fragment } from 'react'

import {
  Breadcrumb,
  BreadcrumbItem,
  BreadcrumbLink,
  BreadcrumbList,
  BreadcrumbSeparator,
} from '@/components/ui/breadcrumb'
import { useUserStore } from '@/store/user'

const breadcrumbNavigationArmenianNames: { [key: string]: string } = {
  blog: 'Բլոգ',
  store: 'Օնլայն խանութ',
  product: 'Օնլայն խանութ',
  akandjogher: 'Ականջօղեր',
  mekhik: 'Մեխիկ',
  qaf: 'Քաֆ',
  oghak: 'Օղակ',
  magltcogh: 'Մագլցող',
  shghthayov: 'Շղթայով',
  kisaoghak: 'Կիսաողակ',
  aparandjanner: 'Ապարանջաններ',
  kakhazarder: 'Կախազարդեր',
  mataniner: 'Մատանիներ',
  vznotcner: 'Վզնոցներ',
  shghthaner: 'Շղթաներ',
  krtsqazarder: 'Կրծքազարդեր',
  cart: 'Զամբյուղ',
  api: 'API',
  'gift-card': 'Նվեր Քարտ',
  'digital-gift-card': 'Օնլայն Նվեր Քարտ',
  profile: 'Հաշիվ',
  orders: 'Պատվերներ',
  favorites: 'Նախընտրածներ',
  'change-password': 'Փոխել Գաղտնաբառը',
  checkout: 'Վճարում',
  'checkout-haypost': 'Վճարում Հայփոստ',
}

const BreadcrumbNavigation = () => {
  const pathname = usePathname()
  const hideBreadCrumb = ['/', '/login', '/register', '/forgot-password']
  const hideBreadCrumbStartsWith = [
    '/reset-password',
    '/unsubscribe',
    '/guest-orders',
    '/api',
  ]
  const currentBreadcrumbItem = useUserStore(
    (state) => state.currentBreadcrumbItem
  )

  const shouldHideBreadcrumb =
    hideBreadCrumb.includes(pathname) ||
    hideBreadCrumbStartsWith.some((path) => pathname.startsWith(path))

  return (
    <div>
      {!shouldHideBreadcrumb && (
        <div className='container py-6'>
          <Breadcrumb>
            <BreadcrumbList>
              <BreadcrumbItem>
                <BreadcrumbLink asChild>
                  <Link href='/'>Գլխավոր</Link>
                </BreadcrumbLink>
              </BreadcrumbItem>
              {pathname.split('/').map((path, index, array) => {
                let url = array.slice(0, index + 1).join('/')
                if (
                  pathname.includes(currentBreadcrumbItem.slug) &&
                  path === 'product'
                ) {
                  url = url.replace('product', 'store')
                }
                const name =
                  path === currentBreadcrumbItem.slug
                    ? currentBreadcrumbItem.name
                    : breadcrumbNavigationArmenianNames[path] ||
                      path.charAt(0).toUpperCase() + path.slice(1)

                return (
                  <Fragment key={index}>
                    <BreadcrumbItem>
                      <BreadcrumbLink asChild>
                        <Link href={url}>{name}</Link>
                      </BreadcrumbLink>
                    </BreadcrumbItem>
                    {index !== pathname.split('/').length - 1 && (
                      <BreadcrumbSeparator />
                    )}
                  </Fragment>
                )
              })}
            </BreadcrumbList>
          </Breadcrumb>
        </div>
      )}
    </div>
  )
}

export default BreadcrumbNavigation
