'use client'

import Image from 'next/image'
import Link from 'next/link'
import Buttons from './Buttons'
import GlobalSearch from './GlobalSearch'
import Nav from './Nav'
import NavMobile from './NavMobile'
import { Suspense } from 'react'
import { useQuery } from '@tanstack/react-query'
import { getHomeData } from '@/server/getHome'
import BreadcrumbNavigation from './BreadcrumbNavigation'

export default function Header() {
  const { data: homeData } = useQuery({
    queryKey: ['home'],
    queryFn: getHomeData,
    staleTime: 1000 * 60 * 60,
  })

  if (!homeData) return <div>Something went wrong</div>

  const customizations = homeData.customizations

  return (
    <>
      <Suspense fallback={<div>Loading...</div>}>
        <header className='sticky top-0 z-20 grid h-24 content-center border-b border-primary bg-background py-4 sm:h-16'>
          <div className='container flex items-center justify-between gap-4'>
            <NavMobile headerData={customizations.headerData} />

            <Link href='/'>
              <Image
                src={customizations.logo.value!}
                alt='Siamoods logo'
                height={62}
                width={170}
                priority
                className='h-[62px] w-[170px] object-contain'
              />
            </Link>

            <Nav className='md:hidden' headerData={customizations.headerData} />
            <GlobalSearch className='md:hidden' />
            <Buttons />
          </div>
        </header>
        <BreadcrumbNavigation />
      </Suspense>
    </>
  )
}
