'use client'

import { useEffect, useState } from 'react'

import { useQuery } from '@tanstack/react-query'

import { getOrder } from '@/server/getOrder'
import { useCheckoutStore } from '@/store/checkout'

import ProductsInfo from './ProductsInfo'
import Total from './Total'
import UserInfo from './UserInfo'

const Order = ({ id }: { id: string }) => {
  const [isMounted, setIsMounted] = useState(false)
  const { data: orderData } = useQuery({
    queryKey: ['orders', { id }],
    queryFn: () => getOrder(id ?? ''),
  })
  const setCheckoutStore = useCheckoutStore((state) => state.setCheckoutStore)
  const navigatedFromCheckout = useCheckoutStore(
    (state) => state.navigatedFromCheckout
  )

  useEffect(() => {
    setIsMounted(true)
    return () => {
      if (isMounted) {
        setCheckoutStore('navigatedFromCheckout', '0')
      }
    }
  }, [])

  return (
    <div className='container flex w-full flex-1 flex-col gap-4'>
      {navigatedFromCheckout === '1' && (
        <h2 className='pb-4 text-xl font-bold'>
          Շնորհակալություն {orderData?.addresses?.shipping_address?.name} Ձեր
          պատվերի գրանցվել է
        </h2>
      )}
      <div className='flex items-center justify-between gap-4 sm:flex-col'>
        <h1>
          <span className='text-xl font-bold sm:text-lg'>
            Պատվեր #{orderData?.order_id}
          </span>{' '}
          ({orderData?.order_date})
        </h1>
        <div>Կարգավիճակ։ {orderData?.order_status}</div>
      </div>
      <div className='flex border-b pt-4'>
        <div className='self-start rounded-t-md bg-muted px-4 py-2'>
          Ընդհանուր
        </div>
      </div>

      <div className='flex flex-col gap-4 p-4 sm:px-0'>
        <UserInfo orderData={orderData} />
        <ProductsInfo orderData={orderData} />
        <Total orderData={orderData} />
      </div>
    </div>
  )
}

export default Order
