import { type ClassValue, clsx } from 'clsx'
import { twMerge } from 'tailwind-merge'

import { InputType } from '@/components/ui/input'

export function cn(...inputs: ClassValue[]) {
  return twMerge(clsx(inputs))
}

export function convertToMoney(
  value: number | string | null | undefined
): string {
  if (!value || value === 0 || value === '0' || value === '') {
    return '0 ֏'
  }
  if (typeof value === 'string' && isNaN(parseFloat(value))) {
    return value
  }
  const numberValue = typeof value === 'string' ? parseFloat(value) : value
  const formattedValue = numberValue.toLocaleString('en-US')
  return formattedValue + ' ֏'
}

export function formatInputValue(
  value: number | string | null | undefined | readonly string[],
  type: InputType
) {
  if (!value) {
    return ''
  }
  if (typeof value === 'number') {
    value = value.toString()
  }
  if (typeof value === 'string') {
    if (type === 'integerWithDecimal') {
      return value.replace(/[^0-9.]/g, '')
    }
    if (type === 'integer') {
      return value.replace(/[^0-9]/g, '')
    }
  }
  return value
}

export function countDashes(s: number | string | null | undefined): number {
  if (typeof s !== 'string') {
    return 0
  }
  return s.split('-').length - 1
}

export function sliceAndGetSlug(s: number | string | null | undefined): string {
  if (typeof s !== 'string') {
    return ''
  }
  return s.split('/').slice(-1)[0]
}

export function cleanObject(obj: unknown): any {
  if (Array.isArray(obj)) {
    return (obj as any[])
      .map((v) => (v && typeof v === 'object' ? cleanObject(v) : v))
      .filter((v) => !(v == null || v === ''))
  } else if (typeof obj === 'object' && obj !== null) {
    return Object.entries(obj as Record<string, unknown>)
      .map(([k, v]) => [k, v && typeof v === 'object' ? cleanObject(v) : v])
      .reduce(
        (a: Record<string, unknown>, [k, v]) =>
          v == null ||
          v === '' ||
          (typeof v === 'object' &&
            Object.keys(v as Record<string, unknown>).length === 0)
            ? a
            : { ...a, [k]: v },
        {}
      )
  }
  return obj
}

export function slicePhoneCode(s: number | string | null | undefined): string {
  if (typeof s !== 'string') {
    return ''
  }
  return s.slice(4)
}

export function handleIdram({
  EDP_REC_ACCOUNT,
  EDP_DESCRIPTION,
  EDP_AMOUNT,
  EDP_BILL_NO,
}: {
  EDP_REC_ACCOUNT: string
  EDP_DESCRIPTION: string
  EDP_AMOUNT: string
  EDP_BILL_NO: string
}) {
  const paymentData = {
    EDP_LANGUAGE: 'AM',
    EDP_REC_ACCOUNT, // payment_info.account
    EDP_DESCRIPTION, // payment_info.description
    EDP_AMOUNT, // payment_info.amount
    EDP_BILL_NO, // payment_key
  }

  const form = document.createElement('form')
  form.method = 'POST'
  form.action = 'https://banking.idram.am/Payment/GetPayment'

  Object.keys(paymentData).forEach((key) => {
    const input = document.createElement('input')
    input.type = 'hidden'
    input.name = key
    input.value = paymentData[key as keyof typeof paymentData]
    form.appendChild(input)
  })

  document.body.appendChild(form)
  form.submit()
}

export function encodeImageUrl(url: string) {
  return url.replace(/\(/g, '%28').replace(/\)/g, '%29')
}
