import axios, { AxiosError, AxiosResponse } from 'axios'
import Cookies from 'js-cookie'

const axiosClient = axios.create({
  baseURL: process.env.NEXT_PUBLIC_API_URL,
})

axiosClient.interceptors.request.use((config) => {
  const token = Cookies.get('siamoods_token')
  const guestToken = Cookies.get('siamoods_token_guest')
  config.headers.Authorization = token ? `Bearer ${token}` : ''

  // Check if there is no token and set the appropriate params
  if (!token) {
    config.params = {
      ...config.params,
      user_unique_id: guestToken,
    }
    config.data = {
      ...config.data,
      user_unique_id: guestToken,
    }
  }

  return config
})

axiosClient.interceptors.response.use(
  (response: AxiosResponse) => {
    // Any status code that lies within the range of 2xx causes this function to trigger
    // Do something with response data
    return response
  },
  (error: AxiosError) => {
    // Any status codes that fall outside the range of 2xx cause this function to trigger
    // Do something with response error
    if (error.response && error.response.status === 401) {
      // Handle 401 error here
      Cookies.remove('siamoods_token')
      window.location.href = '/'
    }
    return Promise.reject(error)
  }
)

export default axiosClient
